==> nomachine-8.9.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXUtmp.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXUtmp;no warnings;($GLOBAL::WTMP_ENTRY="\x6e\x6f");sub add{if (((not (
defined ($GLOBAL::CommandSessreg)))or ($GLOBAL::CommandSessreg eq ("")))){
Logger::debug (
"\x4e\x58\x75\x74\x6d\x70\x20\x6c\x6f\x67\x67\x69\x6e\x67\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);return ((0x0e49+ 5325-0x2316));}(my $display=NXSessionParameters::getDisplay 
());(my $remoteip=NXSessionParameters::getUserIp ());(my $username=
NXSessionParameters::getUsername ());(my $sessionType=
NXSessionParameters::getSessionType ());if (Common::NXSessionType::isUnixConsole
 ($sessionType)){Logger::debug (
"\x55\x6e\x69\x78\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x77\x69\x6c\x6c\x20\x68\x61\x6e\x64\x6c\x65\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x72\x65\x67\x69\x73\x74\x65\x72\x2e"
);return ((0x04ea+ 6299-0x1d85));}if ((not (-x ($GLOBAL::CommandSessreg)))){
Logger::debug ((("\x43\x61\x6e\x6e\x6f\x74\x20\x73\x74\x61\x74\x3a\x20".
$GLOBAL::CommandSessreg)."\x2e"));return ((0x1604+ 4298-0x26ce));}if ((not ((
$display=~ /^.{1,100}$/ )))){Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x64\x69\x73\x70\x6c\x61\x79\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x0714+ 4287-0x17d3));}if ((not (($remoteip=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x72\x65\x6d\x6f\x74\x65\x69\x70\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x0e94+ 3634-0x1cc6));}if ((not (($username=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x0754+ 2898-0x12a6));}Logger::debug ((((((
"\x4e\x58\x55\x74\x6d\x70\x3a".$display)."\x2c").$remoteip)."\x2c").$username));
(my (@command)=());push (@command,$GLOBAL::CommandNXexec,$GLOBAL::SCRIPT_WTMPADD
,$display,$remoteip,$username);(my (@parameters)=());push (@parameters,
"\x75\x73\x65\x20\x73\x63\x72\x69\x70\x74\x20\x74\x6f\x20\x6b\x69\x6c\x6c");(my (
$cmderr,$cmdout,$exit_code)=main::run_command ((\@command),(\@parameters)));if (
$exit_code){Logger::error ((
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x69\x6e\x69\x73\x68\x65\x64\x20\x77\x69\x74\x68\x20\x65\x72\x72\x6f\x72\x73\x3a\x20"
.$cmderr));}else{($GLOBAL::WTMP_ENTRY="\x79\x65\x73");}return (
(0x12d4+ 1327-0x1803));}sub remove{if (((not (defined ($GLOBAL::CommandSessreg))
)or ($GLOBAL::CommandSessreg eq ("")))){Logger::debug (
"\x4e\x58\x75\x74\x6d\x70\x3a\x20\x6c\x6f\x67\x67\x69\x6e\x67\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);return ((0x17b9+ 2500-0x217d));}if (($GLOBAL::WTMP_ENTRY ne "\x79\x65\x73")){
Logger::debug (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x64\x69\x73\x61\x62\x6c\x65\x64");return (
(0x0c92+ 2780-0x176e));}(my $display=NXSessionParameters::getDisplay ());(my $remoteip
=NXSessionParameters::getUserIp ());(my $username=
NXSessionParameters::getUsername ());if ((not (($display=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x61\x72\x67\x75\x6d\x65\x6e\x74\x20\x64\x69\x73\x70\x6c\x61\x79\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x1159+ 981-0x152e));}if ((not (($remoteip=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x72\x65\x6d\x6f\x74\x65\x69\x70\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x1e5f+ 1055-0x227e));}if ((not (($username=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x0b8a+ 2705-0x161b));}(my (@command)=());push (@command,
$GLOBAL::CommandNXexec,$GLOBAL::SCRIPT_WTMPDEL,$display,$remoteip,$username);(my (
@parameters)=());push (@parameters,
"\x75\x73\x65\x20\x73\x63\x72\x69\x70\x74\x20\x74\x6f\x20\x6b\x69\x6c\x6c");(my (
$cmderr,$cmdout,$exit_code)=main::run_command ((\@command),(\@parameters)));if (
$exit_code){Logger::error ((
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x66\x69\x6e\x69\x73\x68\x20\x77\x69\x74\x68\x20\x65\x72\x72\x6f\x72\x73\x3a\x20"
.$cmderr));}return ((0x0ae9+ 4450-0x1c4b));}return ((0x17dc+ 2081-0x1ffc));

==> nomachine-8.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXUtmp.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXUtmp;no warnings;($GLOBAL::WTMP_ENTRY="\x6e\x6f");sub add{if (((not (
defined ($GLOBAL::CommandSessreg)))or ($GLOBAL::CommandSessreg eq ("")))){
Logger::debug (
"\x4e\x58\x75\x74\x6d\x70\x20\x6c\x6f\x67\x67\x69\x6e\x67\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);return ((0x229c+ 301-0x23c9));}(my $display=NXSessionParameters::getDisplay ()
);(my $remoteip=NXSessionParameters::getUserIp ());(my $username=
NXSessionParameters::getUsername ());(my $sessionType=
NXSessionParameters::getSessionType ());if (Common::NXSessionType::isUnixConsole
 ($sessionType)){Logger::debug (
"\x55\x6e\x69\x78\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x77\x69\x6c\x6c\x20\x68\x61\x6e\x64\x6c\x65\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x72\x65\x67\x69\x73\x74\x65\x72\x2e"
);return ((0x073d+ 2504-0x1105));}if ((not (-x ($GLOBAL::CommandSessreg)))){
Logger::debug ((("\x43\x61\x6e\x6e\x6f\x74\x20\x73\x74\x61\x74\x3a\x20".
$GLOBAL::CommandSessreg)."\x2e"));return ((0x0964+ 6713-0x239d));}if ((not ((
$display=~ /^.{1,100}$/ )))){Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x64\x69\x73\x70\x6c\x61\x79\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x0245+ 6591-0x1c04));}if ((not (($remoteip=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x72\x65\x6d\x6f\x74\x65\x69\x70\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x1302+ 843-0x164d));}if ((not (($username=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x1d07+ 576-0x1f47));}Logger::debug ((((((
"\x4e\x58\x55\x74\x6d\x70\x3a".$display)."\x2c").$remoteip)."\x2c").$username));
(my (@command)=());push (@command,$GLOBAL::CommandNXexec,$GLOBAL::SCRIPT_WTMPADD
,$display,$remoteip,$username);(my (@parameters)=());push (@parameters,
"\x75\x73\x65\x20\x73\x63\x72\x69\x70\x74\x20\x74\x6f\x20\x6b\x69\x6c\x6c");(my (
$cmderr,$cmdout,$exit_code)=main::run_command ((\@command),(\@parameters)));if (
$exit_code){Logger::error ((
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x69\x6e\x69\x73\x68\x65\x64\x20\x77\x69\x74\x68\x20\x65\x72\x72\x6f\x72\x73\x3a\x20"
.$cmderr));}else{($GLOBAL::WTMP_ENTRY="\x79\x65\x73");}return (
(0x012d+ 2432-0x0aad));}sub remove{if (((not (defined ($GLOBAL::CommandSessreg))
)or ($GLOBAL::CommandSessreg eq ("")))){Logger::debug (
"\x4e\x58\x75\x74\x6d\x70\x3a\x20\x6c\x6f\x67\x67\x69\x6e\x67\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);return ((0x09bd+ 4053-0x1992));}if (($GLOBAL::WTMP_ENTRY ne "\x79\x65\x73")){
Logger::debug (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x64\x69\x73\x61\x62\x6c\x65\x64");return (
(0x02bb+ 4196-0x131f));}(my $display=NXSessionParameters::getDisplay ());(my $remoteip
=NXSessionParameters::getUserIp ());(my $username=
NXSessionParameters::getUsername ());if ((not (($display=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x61\x72\x67\x75\x6d\x65\x6e\x74\x20\x64\x69\x73\x70\x6c\x61\x79\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x0449+ 6228-0x1c9d));}if ((not (($remoteip=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x72\x65\x6d\x6f\x74\x65\x69\x70\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x0439+ 453-0x05fe));}if ((not (($username=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x0790+ 5125-0x1b95));}(my (@command)=());push (@command,
$GLOBAL::CommandNXexec,$GLOBAL::SCRIPT_WTMPDEL,$display,$remoteip,$username);(my (
@parameters)=());push (@parameters,
"\x75\x73\x65\x20\x73\x63\x72\x69\x70\x74\x20\x74\x6f\x20\x6b\x69\x6c\x6c");(my (
$cmderr,$cmdout,$exit_code)=main::run_command ((\@command),(\@parameters)));if (
$exit_code){Logger::error ((
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x66\x69\x6e\x69\x73\x68\x20\x77\x69\x74\x68\x20\x65\x72\x72\x6f\x72\x73\x3a\x20"
.$cmderr));}return ((0x23dc+ 182-0x2492));}return ((0x105d+ 3778-0x1f1e));
